combine_scaled

Function combine_scaled 

pub fn combine_scaled(a: &FontMatrix, b: &FontMatrix, scale: i32) -> FontMatrix
Simple fixed point matrix multiplication with a scaling factor.

Note: this transforms the translation component of b by the upper 2x2 of a. This matches the offset transform FreeType uses when concatenating the matrices from the top and font dicts.