Transform

Struct Transform 

pub struct Transform {
    pub matrix: FontMatrix,
    pub scale: Option<Fixed>,
}
Combination of a matrix and optional scale.

Fields

matrix: FontMatrix

Affine font matrix.

scale: Option<Fixed>

Fixed point scale factor.

This is assumed to convert from font units to 26.6 values.

Implementations

Source

impl Transform

pub const IDENTITY: Self

The transform that doesn’t modify coordinates or metrics.

pub fn compute_scale(ppem: f32, upem: i32) -> Fixed

Computes a scale factor for the given ppem and upem values.

pub fn transform_h_metric(&self, metric: Fixed) -> Fixed

Applies the transform to a horizontal metric such as an advance width.